Index: samples/github/android/GithubSample/app/src/main/java/com/google/dartino/githubsample/MainApplication.java |
diff --git a/samples/github/android/GithubSample/app/src/main/java/com/google/fletch/githubsample/MainApplication.java b/samples/github/android/GithubSample/app/src/main/java/com/google/dartino/githubsample/MainApplication.java |
similarity index 74% |
rename from samples/github/android/GithubSample/app/src/main/java/com/google/fletch/githubsample/MainApplication.java |
rename to samples/github/android/GithubSample/app/src/main/java/com/google/dartino/githubsample/MainApplication.java |
index 47c8e274733253ee46ec7f480713df847c6a2b91..6f485e7c3fabfa7b101ea16c72ead2f1a5f74219 100644 |
--- a/samples/github/android/GithubSample/app/src/main/java/com/google/fletch/githubsample/MainApplication.java |
+++ b/samples/github/android/GithubSample/app/src/main/java/com/google/dartino/githubsample/MainApplication.java |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-package com.google.fletch.githubsample; |
+package com.google.dartino.githubsample; |
import android.app.Application; |
import android.util.Log; |
@@ -11,9 +11,9 @@ import java.io.ByteArrayOutputStream; |
import java.io.IOException; |
import java.io.InputStream; |
-import fletch.FletchApi; |
-import fletch.FletchServiceApi; |
-import fletch.ImmiServiceLayer; |
+import dartino.DartinoApi; |
+import dartino.DartinoServiceApi; |
+import dartino.ImmiServiceLayer; |
public class MainApplication extends Application { |
@@ -21,7 +21,7 @@ public class MainApplication extends Application { |
static int debugPortNumber = 8123; |
private void startDartServiceThread() { |
// Start a thread waiting for the Fletch debugger to attach. |
if (attachDartDebugger) { |
System.out.println("Waiting for debugger connection on port " + debugPortNumber); |
Thread dartThread = new Thread(new DartDebugger(debugPortNumber)); |
@@ -45,18 +45,18 @@ public class MainApplication extends Application { |
} |
} |
- private class PrintInterceptor extends FletchApi.PrintInterceptor { |
+ private class PrintInterceptor extends DartinoApi.PrintInterceptor { |
@Override public void Out(String message) { Log.i(TAG, message); } |
@Override public void Error(String message) { Log.e(TAG, message); } |
- private static final String TAG = "Fletch"; |
+ private static final String TAG = "Dartino"; |
} |
- private void startFletchService() { |
- System.loadLibrary("fletch"); |
- FletchApi.Setup(); |
- FletchServiceApi.Setup(); |
- FletchApi.AddDefaultSharedLibrary("libfletch.so"); |
- FletchApi.RegisterPrintInterceptor(new PrintInterceptor()); |
+ private void startDartinoService() { |
+ System.loadLibrary("dartino"); |
+ DartinoApi.Setup(); |
+ DartinoServiceApi.Setup(); |
+ DartinoApi.AddDefaultSharedLibrary("libdartino.so"); |
+ DartinoApi.RegisterPrintInterceptor(new PrintInterceptor()); |
startDartServiceThread(); |
ImmiServiceLayer.Setup(); |
} |
@@ -64,6 +64,6 @@ public class MainApplication extends Application { |
@Override |
public void onCreate() { |
super.onCreate(); |
- startFletchService(); |
+ startDartinoService(); |
} |
} |
@@ -21,7 +21,7 @@ public class MainApplication extends Application { |
static int debugPortNumber = 8123; |
private void startDartServiceThread() { |
- // Start a thread waiting for the Fletch debugger to attach. |
+ // Start a thread waiting for the Dartino debugger to attach. |
if (attachDartDebugger) { |
System.out.println("Waiting for debugger connection on port " + debugPortNumber); |